@@ -147,7 +147,7 @@ class Dispatch(object):
 			packUpdate['addrfrom'] = '- %s' % pack['sender']
 			packUpdate['smtpfrom'] = pack['sender']
 		
-		if pack['smtpfrom']:
+		if 'smtpfrom' in pack:
 			if isinstance(pack['smtpfrom'], tuple):
 				packUpdate['smtpfrom'] = pack['smtpfrom'][1]
 			else:
