@@ -15,6 +15,9 @@ from email.MIMEBase import MIMEBase
 from email.MIMEText import MIMEText
 from email.Header import Header
 
+import logging
+log = logging.getLogger("turbomail.message")
+
 
 __all__ = ['Message', 'KIDMessage']
 _rich_to_plain = re.compile(r"(<[^>]+>)")
@@ -226,6 +229,12 @@ class Message(object):
 		if self.encoding == 'utf-8-qp':
 			Charset.add_charset('utf-8', Charset.SHORTEST, Charset.QP, 'utf-8')
 			self.encoding = 'utf-8'
+
+		if callable(self.plain):
+			self.plain = self.plain()
+
+		if callable(self.rich):
+			self.rich = self.rich()
 		
 		if self.rich and not self.plain:
 			self.plain = _rich_to_plain.sub('', self.rich)
@@ -387,6 +396,8 @@ class KIDMessage(Message):
 		                  pass to the template engine.
 		@type variables: dict
 		"""
+
+		log.warn("Use of KIDMessage is deprecated and will be removed in version 2.1.")
 		
 		self._template = template
 		self._variables = dict(sender=sender, recipient=recipient, subject=subject)
@@ -409,57 +420,3 @@ class KIDMessage(Message):
 		self.rich = turbogears.view.engines.get('kid').render(data, template=self._template)
 		
 		return super(KIDMessage, self)._process()
-
-class ControllerMessage(Message):
-	"""A message that accepts a callable and arguments.
-
-	Example usage::
-
-		import turbomail
-		message = turbomail.ControllerMessage(
-				"from@host.com",
-				"to@host.com",
-				"Subject",
-				controller.method,
-				dict()
-			)
-
-	Feel free to set a message.plain content as the controller only
-	returns HTML.  If you wish to hand-produce content, use the
-	Message class.
-	
-	This class can likely be improved to automatically generate the
-	plain text content from processing the HTML, calling two methods,
-	or calling a single method with special arguments.  Needs
-	discussion.
-	"""
-
-	def __init__(self, sender, recipient, subject, method, variables={}, **kw):
-		"""Store the additonal template and variable information.
-
-		@param method: Any callable that returns HTML; usually an
-		               exposed controller method.
-		@type method: callable
-
-		@param variables: A dictionary containing named variables to
-		                  pass to the method.
-		@type variables: dict
-		"""
-
-		self._method = method
-		self._variables = variables
-
-		super(ControllerMessage, self).__init__(sender, recipient, subject, **kw)
-
-	def _process(self):
-		"""Automatically generate the rich text content."""
-
-		data = dict(sender=self.sender, recipient=self.recipient, subject=self.subject)
-
-		for (i, j) in self._variables.iteritems():
-			if callable(j): data[i] = j()
-			else: data[i] = j
-
-		self.rich = self._method(**data)
-
-		return super(ControllerMessage, self)._process()
