@@ -3,7 +3,7 @@
 """TurboGears extension startup and shutdown interface."""
 
 import logging
-log = logging.getLogger("turbomail")
+log = logging.getLogger("turbomail.startup")
 
 import turbogears
 
@@ -11,8 +11,10 @@ import turbomail
 from turbomail.exceptions import *
 from turbomail.pool import MailPool
 
+from email import Charset
 
-__all__ = ['start_extension', 'shutdown_extension']
+
+__all__ = ['start_extension', 'shutdown_extension', 'MailTemplate']
 
 
 def start_extension():
@@ -30,7 +32,11 @@ def start_extension():
 	
 	log.info("Outbound mail queue manager starting.")
 	
-	turbomail.queue = MailPool(
+	if turbogears.config.get("mail.encoding", "us-ascii") == "utf-8-qp":
+		Charset.add_charset('utf-8', Charset.SHORTEST, Charset.QP, 'utf-8')
+		turbogears.config.update({"mail.encoding": "utf-8"})
+	
+	turbomail._queue = MailPool(
 			interval=turbogears.config.get("mail.interval", 10),
 			threads=turbogears.config.get("mail.threads", 4),
 			jobs=turbogears.config.get("mail.jobs", 10),
@@ -39,10 +45,12 @@ def start_extension():
 			username=turbogears.config.get("mail.username", None),
 			password=turbogears.config.get("mail.password", None),
 			debug=turbogears.config.get("mail.debug", False),
-			tls=turbogears.config.get("mail.tls", None)
+			tls=turbogears.config.get("mail.tls", None),
+			polling=turbogears.config.get("mail.polling", None)
 		)
-	turbomail.queue.start()
-	turbomail.enqueue = turbomail.queue.enqueue
+	
+	if turbomail._queue._polling:
+		turbomail.queue.start()
 
 
 def shutdown_extension():
@@ -57,6 +65,5 @@ def shutdown_extension():
 
 	log.info("Outbound mail queue manager shutting down.")
 	
-	turbomail.enqueue = None
-	turbomail.queue.shutdown()
+	# turbomail.queue.shutdown()
 	turbomail.queue = None
